# ALPHAFOLD 3 MODEL PARAMETERS TERMS OF USE

Last Modified: 2024-11-09

[AlphaFold 3](https://blog.google/technology/ai/google-deepmind-isomorphic-alphafold-3-ai-model/)
is an AI model developed by [Google DeepMind](https://deepmind.google/) and
[Isomorphic Labs](https://www.isomorphiclabs.com/). It generates 3D structure
predictions of biological molecules, providing model confidence for the
structure predictions. We make the trained model parameters and output generated
using those available free of charge for certain non-commercial uses, in
accordance with these terms of use and the
[AlphaFold 3 Model Parameters Prohibited Use Policy](https://github.com/google-deepmind/alphafold3/blob/main/WEIGHTS_PROHIBITED_USE_POLICY.md).

**Key things to know when using the AlphaFold 3 model parameters and output**

1.  The AlphaFold 3 model parameters and output are **only** available for
    non-commercial use by, or on behalf of, non-commercial organizations
    (*i.e.*, universities, non-profit organizations and research institutes,
    educational, journalism and government bodies). If you are a researcher
    affiliated with a non-commercial organization, provided **you are not a
    commercial organisation or acting on behalf of a commercial organisation,**
    this means you can use these for your non-commercial affiliated research.
2.  You **must not** use nor allow others to use:
    1.  AlphaFold 3 model parameters or output in connection with **any
        commercial activities, including research** **on behalf of commercial
        organizations;** or
    2.  AlphaFold 3 output to **train machine learning models** or related
        technology for **biomolecular structure prediction** similar to
        AlphaFold 3.
3.  You ***must not* publish or share AlphaFold 3 model parameters**, except
    sharing these within your organization in accordance with these Terms.
4.  You ***can* publish, share and adapt AlphaFold 3 *output*** in accordance
    with these Terms, including the requirements to provide clear notice of any
    modifications you make and that ongoing use of AlphaFold 3 output and
    derivatives are subject to the
    [AlphaFold 3 Output Terms of Use](https://github.com/google-deepmind/alphafold3/blob/main/OUTPUT_TERMS_OF_USE.md).

By using, reproducing, modifying, performing, distributing or displaying any
portion or element of the Model Parameters (as defined below) or otherwise
accepting the terms of this agreement, you agree to be bound by (1) these terms
of use, and (2) the
[AlphaFold 3 Model Parameters Prohibited Use Policy](https://github.com/google-deepmind/alphafold3/blob/main/WEIGHTS_PROHIBITED_USE_POLICY.md)
which is incorporated herein by reference (together, the "**Terms**"), in each
case (a) as modified from time to time in accordance with the Terms, and (b)
between you and (i) if you are from a country in the European Economic Area or
Switzerland, Google Ireland Limited, or (ii) otherwise, Google LLC.

You confirm you are authorized either explicitly or implicitly to enter, and are
entering, into the Terms as an employee on behalf of, or otherwise on behalf of,
your organization.

Please read these Terms carefully. They establish what you can expect from us as
you access and use the AlphaFold 3 Assets (as defined below), and what Google
expects from you. When we say "**you**", we mean the individual or organization
using the AlphaFold 3 Assets. When we say "**we**", "**us**" or "**Google**", we
mean the entities that belong to the Google group of companies, which means
Google LLC and its affiliates.

## 1. Key Definitions

As used in these Terms:

"**AlphaFold 3**" means: (a) the AlphaFold 3 source code made available
[here](https://github.com/google-deepmind/alphafold3/) and licensed under the
terms of the Creative Commons Attribution-NonCommercial-Sharealike 4.0
International (CC-BY-NC-SA 4.0) license and any derivative source code, and (b)
Model Parameters.

"**AlphaFold 3 Assets**" means the Model Parameters and Output.

"**Distribution**" or "**Distribute**" means any transmission, publication, or
other sharing of Output publicly or to any other person.

"**Model Parameters**" means the trained model weights and parameters made
available by Google to organizations (at its sole discretion) for their use in
accordance with these Terms, together with (a) modifications to those weights
and parameters, (b) works based on those weights and parameters, or (c) other
code or machine learning models which incorporate, in full or in part, those
weights and parameters.

"**Output**" means the structure predictions and all ancillary and related
information provided by AlphaFold 3 or using the Model Parameters, together with
any visual representations, computational predictions, descriptions,
modifications, copies, or adaptations that are substantially derived from
Output.

"**Including"** means "**including without limitation**".

## 2. Accessing and using the AlphaFold 3 Assets

Subject to your compliance with the Terms, including the
[AlphaFold 3 Model Parameters Prohibited Use Policy](https://github.com/google-deepmind/alphafold3/blob/main/WEIGHTS_PROHIBITED_USE_POLICY.md),
you may access, use and modify the AlphaFold 3 Assets and Distribute the Output
as set out in these Terms. We grant you a non-exclusive, royalty-free,
revocable, non-transferable and non-sublicensable (except as expressly permitted
in these Terms) license to any intellectual property rights we have in the
AlphaFold Assets to the extent necessary for these purposes. In order to verify
your access and use of AlphaFold 3, we may from time-to-time ask for additional
information from you, including verification of your name, organization, and
other identifying information.

By accessing, using, or modifying the AlphaFold 3 Assets, Distributing Output,
or requesting to access the Model Parameters, you represent and warrant that (a)
you have full power and authority to enter into these Terms (including being of
sufficient age of consent), (b) Google has never previously terminated your
access and right to use AlphaFold 3 (including as made available via
[AlphaFold Server](https://alphafoldserver.com/about)) due to your breach of
applicable terms of use, (c) entering into or performing your rights and
obligations under these Terms will not violate any agreement you have with a
third party or any third-party rights, (d) any information provided by you to
Google in relation to AlphaFold 3, including (where applicable) in order to
request access to the Model Parameters, is correct and current, and (e) you are
not (i) resident of a embargoed country, (ii) ordinarily resident in a US
embargoed country, or (iii) otherwise prohibited by applicable export controls
and sanctions programs from accessing, using, or modifying the AlphaFold 3
Assets.

If you choose to give Google feedback, such as suggestions to improve AlphaFold
3, you undertake any such information is non-confidential and non-proprietary,
and Google may act on your feedback without obligation to you.

## 3. Use Restrictions

You must not use any of the AlphaFold 3 Assets:

1.  for the restricted uses set forth in the
    [AlphaFold 3 Model Parameters Prohibited Use Policy](https://github.com/google-deepmind/alphafold3/blob/main/WEIGHTS_PROHIBITED_USE_POLICY.md);
    or
2.  in violation of applicable laws and regulations.

To the maximum extent permitted by law and without limiting any of our other
rights, Google reserves the right to revoke your right to use, and (to the
extent feasible) restrict usage of any of the AlphaFold 3 Assets that Google
reasonably believes is in violation of these Terms.

## 4. Generated Output

Although you must comply with these Terms when using the AlphaFold 3 Assets, we
will not claim ownership in original Output you generate using AlphaFold 3.
However, you acknowledge that AlphaFold 3 may generate the same or similar
Output for multiple users, including Google, and we reserve all our rights in
this respect.

## 5. Changes to the AlphaFold 3 Assets or these Terms

Google may add or remove functionalities or features of the AlphaFold 3 Assets
at any time and may stop offering access to the AlphaFold 3 Assets altogether.

Google may update these Terms and the access mechanism for the Model Parameters
at any time. We'll post any modifications to the Terms
[in the AlphaFold 3 GitHub repository](https://github.com/google-deepmind/alphafold3).
Changes will generally become effective 14 days after they are posted. However,
changes addressing functionality or made for legal reasons will be effective
immediately.

You should review the Terms whenever we update them or you use the AlphaFold 3
Assets. If you do not agree to any modifications to the Terms, you must stop
using the AlphaFold 3 Assets immediately.

## 6. Suspending or terminating your right to use the AlphaFold 3 Assets

Google may at any time suspend or terminate your right to use and, as applicable
access to, the AlphaFold 3 Assets because of, among other reasons, your failure
to fully comply with the Terms. If Google suspends or terminates your right to
access or use the AlphaFold 3 Assets, you must immediately delete and cease use
and Distribution of all copies of the AlphaFold 3 Assets in your possession or
control and are prohibited from using the AlphaFold 3 Assets, including by
submitting an application to use the Model Parameters. Google will endeavour to
give you reasonable notice prior to any such suspension or termination, but no
notice or prior warning will be given if the suspension or termination is for
your failure to fully comply with the Terms or other serious grounds.

Of course, you are always free to stop using the AlphaFold 3 Assets. If you do
stop using these, we would appreciate knowing why (via
[alphafold@google.com](mailto:alphafold@google.com)) so that we can continue to
improve our technologies.

## 7. Confidentiality

You agree not to disclose or make available Google Confidential Information to
anyone without our prior written consent. "**Google Confidential Information**"
means (a) the AlphaFold 3 Model Parameters and all software, technology and
documentation relating to AlphaFold 3, except for the AlphaFold 3 source code,
and (b) any other information made available by Google that is marked
confidential or would normally be considered confidential under the
circumstances in which it is presented. Google Confidential Information does not
include (a) information that you already knew prior to your access to, or use
of, the AlphaFold 3 Assets (including via
[AlphaFold Server](https://alphafoldserver.com/about)), (b) that becomes public
through no fault of yours (for example, your breach of the Terms), (c) that was
independently developed by you without reference to Google Confidential
Information, or (d) that was lawfully given to you by a third party (without
your or their breach of the Terms).

## 8. Disclaimers

Nothing in the Terms restricts any rights that cannot be restricted under
applicable law or limits Google's responsibilities except as allowed by
applicable law.

**AlphaFold 3 and Output are provided on an "as is" basis, without warranties or
conditions of any kind, either express or implied, including any warranties or
conditions of title, non-infringement, merchantability, or fitness for a
particular purpose. You are solely responsible for determining the
appropriateness of using AlphaFold 3, or using or distributing Output, and
assume any and all risks associated with such use or distribution and your
exercise of rights and obligations under these Terms. You and anyone you share
Output with are solely responsible for these and their subsequent uses.**

**Output are predictions with varying levels of confidence and should be
interpreted carefully. Use discretion before relying on, publishing, downloading
or otherwise using AlphaFold 3.**

**AlphaFold 3 and Outputs are for theoretical modeling only. They are not
intended, validated, or approved for clinical use. You should not use AlphaFold
3 or Output for clinical purposes or rely on them for medical or other
professional advice. Any content regarding those topics is provided for
informational purposes only and is not a substitute for advice from a qualified
professional.**

## 9. Liabilities

To the extent allowed by applicable law, you will indemnify Google and its
directors, officers, employees, and contractors for any third-party legal
proceedings (including actions by government authorities) arising out of or
relating to your unlawful use of the AlphaFold 3 Assets or violation of the
Terms. This indemnity covers any liability or expense arising from claims,
losses, damages, judgments, fines, litigation costs, and legal fees, except to
the extent a liability or expense is caused by Google's breach, negligence, or
willful misconduct. If you are legally exempt from certain responsibilities,
including indemnification, then those responsibilities do not apply to you under
the Terms.

In no circumstances will Google be responsible for any indirect, special,
incidental, exemplary, consequential, or punitive damages, or lost profits of
any kind in connection with the Terms or the AlphaFold 3 Assets, even if Google
has been advised of the possibility of such damages. Google's total aggregate
liability for all claims arising out of or in connection with the Terms or the
AlphaFold 3 Assets, including for its own negligence, is limited to $500.

## 10. Miscellaneous

By law, you have certain rights that cannot be limited by a contract like the
Terms. The Terms are in no way intended to restrict those rights.

The Terms are our entire agreement relating to your use of the AlphaFold 3
Assets and supersede any prior or contemporaneous agreements on that subject.

If it turns out that a particular provision of the Terms is not enforceable, the
balance of the Terms will remain in full force and effect.

## 11. Disputes

California law will govern all disputes arising out of or relating to the Terms
or in connection to the AlphaFold 3 Assets. These disputes will be resolved
exclusively in the federal or state courts of Santa Clara County, California,
USA and you and Google consent to personal jurisdiction in those courts. To the
extent that applicable local law prevents certain disputes from being resolved
in a California court, you and Google can file those disputes in your local
courts. If applicable local law prevents your local court from applying
California law to resolve these disputes, then these disputes will be governed
by the applicable local laws of your country, state, or other place of
residence. If you are using the AlphaFold 3 Assets on behalf of a government
organization other than US federal government organizations (where the foregoing
provisions shall apply to the extent permitted by federal law), these Terms will
be silent regarding governing law and courts.

Given the nature of scientific research, it may take some time for any breach of
the Terms to become apparent. To protect you, Google and the AlphaFold 3 Assets,
to the extent allowed by applicable law you agree that:

1.  any legal claims relating to the Terms or the AlphaFold 3 Assets can be
    initiated until the later of:
    1.  the cut-off date under applicable law for bringing the legal claim; or
    2.  two years from the date you or Google (as applicable) became aware, or
        should reasonably have become aware, of the facts giving rise to that
        claim; and
2.  you will not argue limitation, time bar, delay, waiver, or the like in an
    attempt to bar an action filed within that time period, and neither will
    Google.

All rights not specifically and expressly granted to you by the Terms are
reserved to Google. No delay, act or omission by Google in exercising any right
or remedy will be deemed a waiver of any breach of the Terms and Google
expressly reserves any and all rights and remedies available under the Terms or
at law or in equity or otherwise, including the remedy of injunctive relief
against any threatened or actual breach of the Terms without the necessity of
proving actual damages.
